__all__ = ('CreditScoringTaskPoint',)

from expressmoney.api import *


SERVICE = 'profiles'
APP = 'credit_scoring'


class CreditScoringTaskReadContract(Contract):
    EMPTY = 'EMPTY'
    SUCCESS = 'SCS'
    FAILURE = 'FAIL'
    RESULT_CHOICES = (
        (EMPTY, EMPTY),
        (FAILURE, FAILURE),
        (SUCCESS, SUCCESS),
    )
    RU = 'RU'
    COUNTRY_CHOICES = (
        (RU, RU),
    )
    id = serializers.IntegerField(min_value=1)
    created = serializers.DateTimeField()
    user_id = serializers.IntegerField(min_value=1)
    country = serializers.ChoiceField(choices=COUNTRY_CHOICES)
    result = serializers.ChoiceField(choices=RESULT_CHOICES)
    score = serializers.DecimalField(max_digits=3, decimal_places=2, allow_null=True)
    comment = serializers.CharField(max_length=1024, allow_blank=True)


class CreditScoringTaskID(ID):
    _service = SERVICE
    _app = APP
    _view_set = 'credit_scoring_task'


class CreditScoringTaskPoint(ListPointMixin, ContractPoint):
    _point_id = CreditScoringTaskID()
    _read_contract = CreditScoringTaskReadContract



__all__ = ('WalletPoint', 'WalletObjectPoint', 'WalletInfoRequestPoint', 'FindWalletPoint')

from expressmoney.api import *
from phonenumber_field.serializerfields import PhoneNumberField

SERVICE = 'wallets'
APP = 'wallets'


class WalletCreateContract(Contract):
    RUB = 'RUB'
    USD = 'USD'
    CURRENCY_CODE_CHOICES = (
        (RUB, RUB),
        (USD, USD),
    )
    currency_code = serializers.ChoiceField(choices=CURRENCY_CODE_CHOICES)


class WalletReadContract(WalletCreateContract):
    id = serializers.IntegerField(min_value=1)
    is_active = serializers.BooleanField()
    user_id = serializers.IntegerField(min_value=1)
    balance = serializers.DecimalField(max_digits=16, decimal_places=0)


class WalletInfoRequestCreateContract(Contract):
    wallet_id = serializers.IntegerField(min_value=1)


class WalletInfoResponseRetrieveContract(WalletInfoRequestCreateContract):
    wallet_is_active = serializers.BooleanField()
    wallet_user_id = serializers.IntegerField(min_value=1)
    wallet_currency_code = serializers.ChoiceField(choices=WalletCreateContract.CURRENCY_CODE_CHOICES)


class FindWalletCreateContract(Contract):
    username = PhoneNumberField()
    currency_code = serializers.ChoiceField(choices=WalletCreateContract.CURRENCY_CODE_CHOICES)


class FindWalletResponseContract(Contract):
    wallet_id = serializers.IntegerField(min_value=1)


class WalletID(ID):
    _service = SERVICE
    _app = APP
    _view_set = 'wallet'


class WalletInfoRequestID(ID):
    _service = SERVICE
    _app = APP
    _view_set = 'wallet_info_request'


class FindWalletID(ID):
    _service = SERVICE
    _app = APP
    _view_set = 'find_wallet'


class WalletPoint(ListPointMixin, CreatePointMixin, ContractPoint):
    _point_id = WalletID()
    _create_contract = WalletCreateContract
    _read_contract = WalletReadContract


class WalletObjectPoint(RetrievePointMixin, ContractObjectPoint):
    _point_id = WalletID()
    _read_contract = WalletReadContract


class WalletInfoRequestPoint(ResponseMixin, CreatePointMixin, ContractPoint):
    _point_id = WalletInfoRequestID()
    _create_contract = WalletInfoRequestCreateContract
    _response_contract = WalletInfoResponseRetrieveContract


class FindWalletPoint(ResponseMixin, CreatePointMixin, ContractPoint):
    _point_id = FindWalletID()
    _create_contract = FindWalletCreateContract
    _response_contract = FindWalletResponseContract



__all__ = ('CorrespondentAccountPoint', 'CorrespondentAccountObjectPoint')

from expressmoney.api import *

SERVICE = 'transfers'
APP = 'accounts'


class CorrespondentAccountDescriptionReadContract(Contract):
    RUB = 'RUB'
    USD = 'USD'
    CURRENCY_CODE_CHOICES = (
        (RUB, RUB),
        (USD, USD),
    )
    currency_code = serializers.ChoiceField(choices=CURRENCY_CODE_CHOICES)


class TrustLevelReadContract(Contract):
    LEVEL_0 = 'LEVEL_0'
    LEVEL_1 = 'LEVEL_1'
    LEVEL_2 = 'LEVEL_2'
    LEVEL_3 = 'LEVEL_3'
    LEVEL_4 = 'LEVEL_4'
    LEVEL_5 = 'LEVEL_5'
    NAME_CHOICES = (
        (LEVEL_0, LEVEL_0),
        (LEVEL_1, LEVEL_1),
        (LEVEL_2, LEVEL_2),
        (LEVEL_3, LEVEL_3),
        (LEVEL_4, LEVEL_4),
        (LEVEL_5, LEVEL_5),
    )
    name = serializers.ChoiceField(choices=NAME_CHOICES)
    currency_code = serializers.ChoiceField(choices=CorrespondentAccountDescriptionReadContract.CURRENCY_CODE_CHOICES)
    amount_min = serializers.DecimalField(max_digits=16, decimal_places=0)
    amount_max = serializers.DecimalField(max_digits=16, decimal_places=0)


class CorrespondentAccountReadContract(Contract):
    id = serializers.IntegerField(min_value=1)
    is_active = serializers.BooleanField()
    user_id = serializers.IntegerField(min_value=1)
    description = CorrespondentAccountDescriptionReadContract()
    trust_level = TrustLevelReadContract()
    balance = serializers.DecimalField(max_digits=16, decimal_places=0)


class CorrespondentAccountID(ID):
    _service = SERVICE
    _app = APP
    _view_set = 'correspondent_account'


class CorrespondentAccountPoint(ListPointMixin, ContractPoint):
    _point_id = CorrespondentAccountID()
    _read_contract = CorrespondentAccountReadContract


class CorrespondentAccountObjectPoint(RetrievePointMixin, ContractObjectPoint):
    _point_id = CorrespondentAccountID()
    _read_contract = CorrespondentAccountReadContract
